@@ -348,7 +348,7 @@ class WalkSFTP:
         store_thread.start()
 
         if callable(self.processing_function):
-            self.print_out('STARTED PROCESSING FUNCTION')
+            self.class_print('STARTED PROCESSING FUNCTION')
             process_thread = Thread(target=self.process_all_ftp, name='process')
             process_thread.start()
 
@@ -381,37 +381,39 @@ class WalkSFTP:
         sleep_count = 0
         while True:
 
+            try:
+                fname = self.process_q.get()
+                self.class_print('process all ftp finished get {}'.format(fname))
 
-            fname = self.process_q.get()
-            self.class_print('process all ftp finished get {}'.format(fname))
+                if fname is None:
+                    self.class_print('process_all_ftp SLEEPING')
+                    sleep(1)
+                    sleep_count += 1
 
-            if fname is None:
-                self.class_print('process_all_ftp SLEEPING')
-                sleep(1)
-                sleep_count += 1
+                elif isinstance(fname[0], str) and fname[0] != 'break':
+                    count+=1
+                    successful_process = self.processing_function(fname[0])
+                    self.add_log(fname[1], 'process', successful_process)
+                    self.class_print(f'process count is {count}')
+                    sleep_count = 0
 
-            elif isinstance(fname[0], str) and fname[0] != 'break':
-                count+=1
-                successful_process = self.processing_function(fname[0])
-                self.add_log(fname[1], 'process', successful_process)
-                self.class_print(f'process count is {count}')
-                sleep_count = 0
+                elif (isinstance(fname[0], str) and fname[0] == 'break') or (count>break_count):
+                    self.class_print('JOINING THREADS')
+                    self.join_threads = True
+                    return None
 
-            elif (isinstance(fname[0], str) and fname[0] == 'break') or (count>break_count):
-                self.class_print('JOINING THREADS')
-                self.join_threads = True
-                return None
+                elif sleep_count > self.max_sleep_count:
+                    self.class_print('JOINING THREADS')
+                    self.join_threads = True
+                    return None
 
-            elif sleep_count > self.max_sleep_count:
-                self.class_print('JOINING THREADS')
-                self.join_threads = True
-                return None
-
-            else:
-                count+=1
-                if count > 1000000000:
-                    self.class_print('still looping process_all_ftp')
-                    count = 0
+                else:
+                    count+=1
+                    if count > 1000000000:
+                        self.class_print('still looping process_all_ftp')
+                        count = 0
+            except Exception as e:
+                print(f'ERROR: {e}')
 
 
 
